@@ -11,15 +11,11 @@
 
 open Misc
 
-let header = "$Id: auxx.ml,v 1.21 2006/02/24 16:43:25 maranget Exp $" 
-
 let rtable = Hashtbl.create 17
 ;;
 
-let rset name value =
-  Hashtbl.add rtable name value
+let rset name value = Hashtbl.add rtable name value
 ;;
-
   
 let rget name =
   try Hashtbl.find rtable name with Not_found -> begin
@@ -55,6 +51,7 @@ let read_digest name =
   with
   | Sys_error _ -> None
 
+let labelcount = ref 0
 let rseen = Hashtbl.create 17
 and bseen = Hashtbl.create 17
 ;;
@@ -99,11 +96,13 @@ let rcheck key =
   try
     let _ = Hashtbl.find rseen key in
     warning ("Multiple definitions for label: "^key) ;
-    false
+    -1
   with
   | Not_found ->
-      Hashtbl.add rseen key () ;
-      true
+      let x = !labelcount in
+      incr labelcount ;
+      Hashtbl.add rseen key x ;
+      x
 
 let swrite msg = match !auxfile with
 | None -> ()
@@ -122,7 +121,8 @@ let bwrite key pretty =
         output_string file "}\n")
 
 and rwrite key pretty =
-  if rcheck key then
+  let idx = rcheck key in
+  if idx >= 0 then
     write
       (fun file ->
         output_string file "\\newlabel{" ;
@@ -130,6 +130,18 @@ and rwrite key pretty =
         output_string file "}{{" ;
         output_string file pretty ;
         output_string file "}{X}}\n")
+and rwrite2 anchor key pretty =
+  let idx =  rcheck key in
+  if idx >= 0 then
+    write
+      (fun file ->
+        output_string file "\\new@anchor@label{" ;
+        output_string file anchor ;
+        output_string file "}{" ;
+        output_string file key ;
+        output_string file "}{{" ;
+        output_string file pretty ;
+        output_string file "}{X}}\n")
 ;;
 
 type toc_t =
@@ -206,19 +218,24 @@ let final base =
 
 
 type saved =
-(string, string) Hashtbl.t * (string, unit) Hashtbl.t *
+(string, string) Hashtbl.t *
+  int * (string, int) Hashtbl.t *
   (string, string) Hashtbl.t * (string, unit) Hashtbl.t *
   out_channel option * string * bool * Digest.t option
 
 let check () =
-  Hashtbl.copy rtable,  Hashtbl.copy rseen,
+  Hashtbl.copy rtable,
+  !labelcount,
+  Hashtbl.copy rseen,
   Hashtbl.copy btable,  Hashtbl.copy  bseen,
   !auxfile, !auxname, !something, !digest
 
 let hot
- (srtable, srseen, sbtable, sbseen,
+ (srtable, slabelcount, srseen, sbtable, sbseen,
   sauxfile, sauxname, ssomething, sdigest) =
-  Misc.copy_hashtbl srtable rtable ; Misc.copy_hashtbl srseen rseen ;
+  Misc.copy_hashtbl srtable rtable ;
+  labelcount := slabelcount  ;
+  Misc.copy_hashtbl srseen rseen ;
   Misc.copy_hashtbl sbtable btable ; Misc.copy_hashtbl sbseen bseen ;
   auxfile := sauxfile ;
   auxname := sauxname ;
@@ -227,7 +244,7 @@ let hot
 
 (* Valid only juste before reading main input file *)
 let hot_start () =
-  Hashtbl.clear rtable ; Hashtbl.clear rseen ;
+  Hashtbl.clear rtable ; labelcount := 0 ; Hashtbl.clear rseen ;
   Hashtbl.clear btable ; Hashtbl.clear bseen ;
   auxfile :=  None ;
   auxname := "" ;
