@@ -7,7 +7,7 @@
 (*  Copyright 2001 Institut National de Recherche en Informatique et   *)
 (*  Automatique.  Distributed only by permission.                      *)
 (*                                                                     *)
-(*  $Id: lexeme.mli,v 1.6 2005/06/24 08:32:21 maranget Exp $           *)
+(*  $Id: lexeme.mli,v 1.6 2005-06-24 08:32:21 maranget Exp $           *)
 (***********************************************************************)
 type tag =
   | TT |I |B |BIG |SMALL
@@ -16,9 +16,21 @@ type tag =
   | KBD |VAR |CITE |ABBR |ACRONYM 
   | Q |SUB |SUP | A | SCRIPT | SPAN | STYLE
 
+(* style for fonts by span tags *)
+type fontstyle =
+  | Ffamily
+  | Fstyle
+  | Fvariant
+  | Fweight
+  | Fsize
+  | Fcolor
+  | Fbgcolor
+
+
 type atag =
   | SIZE of string | COLOR of string | FACE of string
   | CLASS of string
+  | ASTYLE of fontstyle * string
   | OTHER
 
 type attr = atag * string
