@@ -2,19 +2,6 @@
 
 . ./config.sh
 
-ocamlbuild -version > /dev/null 2>/dev/null || \
-case $1 in
-  opt|byte|both)
-     make $1-make
-     exit 0
-     ;;
-  clean)
-     exit 0
-     ;;
-  *) echo "Bad ocb argument '$1'"
-     exit 2
-esac
-
 OCBOCAMLFLAGS=''
 for i in $OCAMLFLAGS
 do
