@@ -11,7 +11,7 @@
 open Lexstate
 module type S = sig
 exception Error of string
-type block
+
 val set_out : Out.t -> unit
 val stop : unit -> unit
 val restart : unit -> unit
@@ -89,7 +89,7 @@ val put_in_math : string -> unit
 
 val open_table : bool -> string -> unit
 val new_row : unit -> unit
-val open_cell : Tabular.format -> int -> int -> unit
+val open_cell : Tabular.format -> int -> int -> bool -> unit
 val erase_cell : unit -> unit
 val close_cell : string -> unit
 val do_close_cell : unit -> unit
